/**
 * SECTION:PositionManager
 * @short_description: Handles computing any size/position information for the dock.
 */
/**
 * PLANK_TYPE_POSITION_MANAGER:
 * 
 * The type for <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link>.
 */
/**
 * plank_position_manager_initialize:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Initializes the position manager.
 */
/**
 * plank_position_manager_reset_caches:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @theme: (in): &nbsp;.  the current dock theme 
 * 
 * Resets all internal caches.
 */
/**
 * plank_position_manager_get_cursor_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Returns the cursor region for the dock. This is the region that the cursor can interact with the dock.
 * 
 * Returns: the cursor region for the dock 
 */
/**
 * plank_position_manager_get_static_dock_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Returns the static dock region for the dock. This is the region that the dock occupies when not hidden.
 * 
 * Returns: the static dock region for the dock 
 */
/**
 * plank_position_manager_update_regions:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Call when any cached region needs updating.
 */
/**
 * plank_position_manager_item_draw_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @hover_rect: (in): &nbsp;.  the item&apos;s hover region 
 * 
 * The region for drawing a dock item.
 * 
 * Returns: the region for the dock item 
 */
/**
 * plank_position_manager_item_background_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @rect: (in): &nbsp;.  the item&apos;s hover region 
 * 
 * The intersecting region of a dock item&apos;s hover region and the background.
 * 
 * Returns: the region for the dock item 
 */
/**
 * plank_position_manager_item_hover_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @item: (in): &nbsp;.  the dock item to find a region for 
 * 
 * The cursor region for interacting with a dock item.
 * 
 * Returns: the region for the dock item 
 */
/**
 * plank_position_manager_get_menu_position:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @hovered: (in): &nbsp;.  the item that is hovered 
 * @requisition: (in): &nbsp;.  the menu&apos;s requisition 
 * @x: (out) (transfer full): &nbsp;.  the resulting x position 
 * @y: (out) (transfer full): &nbsp;.  the resulting y position 
 * 
 * Get&apos;s the x and y position to display a menu for a dock item.
 */
/**
 * plank_position_manager_get_hover_position:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @hovered: (in): &nbsp;.  the item that is hovered 
 * @x: (out) (transfer full): &nbsp;.  the resulting x position 
 * @y: (out) (transfer full): &nbsp;.  the resulting y position 
 * 
 * Get&apos;s the x and y position to display a hover window for a dock item.
 */
/**
 * plank_position_manager_get_urgent_glow_position:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @item: (in): &nbsp;.  the item to show urgent-glow for 
 * @x: (out): &nbsp;.  the resulting x position 
 * @y: (out): &nbsp;.  the resulting y position 
 * 
 * Get&apos;s the x and y position to display the urgent-glow for a dock item.
 */
/**
 * plank_position_manager_update_dock_position:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Caches the x and y position of the dock window.
 */
/**
 * plank_position_manager_get_dock_draw_position:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @x: (out): &nbsp;.  the resulting x position 
 * @y: (out): &nbsp;.  the resulting y position 
 * 
 * Get&apos;s the x and y position to display the main dock buffer.
 */
/**
 * plank_position_manager_get_background_region:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * 
 * Get&apos;s the region for background of the dock.
 * 
 * Returns: the region for the dock background 
 */
/**
 * plank_position_manager_get_icon_geometry:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @item: (in): &nbsp;.  an application-dockitem of the dock 
 * @for_hidden: (in): &nbsp;.  whether the geometry should apply for a hidden dock 
 * 
 * Get the item&apos;s icon geometry for the dock.
 * 
 * Returns: icon geometry for the given application-dockitem 
 */
/**
 * plank_position_manager_get_struts:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance
 * @struts: (inout) (array length=struts_length1): &nbsp;.  the array to contain the struts 
 * @struts_length1: length of the @struts array
 * 
 * Computes the struts for the dock.
 */
/**
 * plank_position_manager_new:
 * @controller: (in): &nbsp;.  the dock controller to manage positions for 
 * 
 * Creates a new position manager.
 */
/**
 * PlankPositionManager:controller:
 */
/**
 * plank_position_manager_set_controller:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to modify
 * @value: the new value of the <link linkend="PlankPositionManager--controller"><type>"controller"</type></link> property
 * 
 * Set the value of the <link linkend="PlankPositionManager--controller"><type>"controller"</type></link> property to @value.
 * 
 * 
 */
/**
 * PlankPositionManager:win-x:
 * 
 * Cached x position of the dock window.
 */
/**
 * plank_position_manager_get_win_x:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--win-x"><type>"win-x"</type></link> property.
 * 
 * Cached x position of the dock window.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--win-x"><type>"win-x"</type></link> property
 */
/**
 * plank_position_manager_set_win_x:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to modify
 * @value: the new value of the <link linkend="PlankPositionManager--win-x"><type>"win-x"</type></link> property
 * 
 * Set the value of the <link linkend="PlankPositionManager--win-x"><type>"win-x"</type></link> property to @value.
 * 
 * Cached x position of the dock window.
 */
/**
 * PlankPositionManager:win-y:
 * 
 * Cached y position of the dock window.
 */
/**
 * plank_position_manager_get_win_y:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--win-y"><type>"win-y"</type></link> property.
 * 
 * Cached y position of the dock window.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--win-y"><type>"win-y"</type></link> property
 */
/**
 * plank_position_manager_set_win_y:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to modify
 * @value: the new value of the <link linkend="PlankPositionManager--win-y"><type>"win-y"</type></link> property
 * 
 * Set the value of the <link linkend="PlankPositionManager--win-y"><type>"win-y"</type></link> property to @value.
 * 
 * Cached y position of the dock window.
 */
/**
 * PlankPositionManager:LineWidth:
 */
/**
 * plank_position_manager_get_LineWidth:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--LineWidth"><type>"LineWidth"</type></link> property.
 * 
 * 
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--LineWidth"><type>"LineWidth"</type></link> property
 */
/**
 * PlankPositionManager:IconSize:
 */
/**
 * plank_position_manager_get_IconSize:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--IconSize"><type>"IconSize"</type></link> property.
 * 
 * 
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--IconSize"><type>"IconSize"</type></link> property
 */
/**
 * PlankPositionManager:IndicatorSize:
 * 
 * Theme-based indicator size, scaled by icon size.
 */
/**
 * plank_position_manager_get_IndicatorSize:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--IndicatorSize"><type>"IndicatorSize"</type></link> property.
 * 
 * Theme-based indicator size, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--IndicatorSize"><type>"IndicatorSize"</type></link> property
 */
/**
 * PlankPositionManager:IconShadowSize:
 * 
 * Theme-based icon-shadow size, scaled by icon size.
 */
/**
 * plank_position_manager_get_IconShadowSize:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--IconShadowSize"><type>"IconShadowSize"</type></link> property.
 * 
 * Theme-based icon-shadow size, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--IconShadowSize"><type>"IconShadowSize"</type></link> property
 */
/**
 * PlankPositionManager:GlowSize:
 * 
 * Theme-based urgent glow size, scaled by icon size.
 */
/**
 * plank_position_manager_get_GlowSize:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--GlowSize"><type>"GlowSize"</type></link> property.
 * 
 * Theme-based urgent glow size, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--GlowSize"><type>"GlowSize"</type></link> property
 */
/**
 * PlankPositionManager:HorizPadding:
 * 
 * Theme-based horizontal padding, scaled by icon size.
 */
/**
 * plank_position_manager_get_HorizPadding:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--HorizPadding"><type>"HorizPadding"</type></link> property.
 * 
 * Theme-based horizontal padding, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--HorizPadding"><type>"HorizPadding"</type></link> property
 */
/**
 * PlankPositionManager:TopPadding:
 * 
 * Theme-based top padding, scaled by icon size.
 */
/**
 * plank_position_manager_get_TopPadding:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--TopPadding"><type>"TopPadding"</type></link> property.
 * 
 * Theme-based top padding, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--TopPadding"><type>"TopPadding"</type></link> property
 */
/**
 * PlankPositionManager:BottomPadding:
 * 
 * Theme-based bottom padding, scaled by icon size.
 */
/**
 * plank_position_manager_get_BottomPadding:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--BottomPadding"><type>"BottomPadding"</type></link> property.
 * 
 * Theme-based bottom padding, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--BottomPadding"><type>"BottomPadding"</type></link> property
 */
/**
 * PlankPositionManager:ItemPadding:
 * 
 * Theme-based item padding, scaled by icon size.
 */
/**
 * plank_position_manager_get_ItemPadding:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--ItemPadding"><type>"ItemPadding"</type></link> property.
 * 
 * Theme-based item padding, scaled by icon size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--ItemPadding"><type>"ItemPadding"</type></link> property
 */
/**
 * PlankPositionManager:UrgentBounceHeight:
 */
/**
 * plank_position_manager_get_UrgentBounceHeight:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--UrgentBounceHeight"><type>"UrgentBounceHeight"</type></link> property.
 * 
 * 
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--UrgentBounceHeight"><type>"UrgentBounceHeight"</type></link> property
 */
/**
 * PlankPositionManager:VisibleDockHeight:
 * 
 * The currently visible height of the dock.
 */
/**
 * plank_position_manager_get_VisibleDockHeight:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--VisibleDockHeight"><type>"VisibleDockHeight"</type></link> property.
 * 
 * The currently visible height of the dock.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--VisibleDockHeight"><type>"VisibleDockHeight"</type></link> property
 */
/**
 * PlankPositionManager:DockHeight:
 * 
 * The static height of the dock.
 */
/**
 * plank_position_manager_get_DockHeight:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--DockHeight"><type>"DockHeight"</type></link> property.
 * 
 * The static height of the dock.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--DockHeight"><type>"DockHeight"</type></link> property
 */
/**
 * PlankPositionManager:DockBackgroundHeight:
 * 
 * The height of the dock&apos;s background image.
 */
/**
 * plank_position_manager_get_DockBackgroundHeight:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--DockBackgroundHeight"><type>"DockBackgroundHeight"</type></link> property.
 * 
 * The height of the dock&apos;s background image.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--DockBackgroundHeight"><type>"DockBackgroundHeight"</type></link> property
 */
/**
 * PlankPositionManager:VisibleDockWidth:
 * 
 * The currently visible width of the dock.
 */
/**
 * plank_position_manager_get_VisibleDockWidth:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--VisibleDockWidth"><type>"VisibleDockWidth"</type></link> property.
 * 
 * The currently visible width of the dock.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--VisibleDockWidth"><type>"VisibleDockWidth"</type></link> property
 */
/**
 * PlankPositionManager:DockWidth:
 * 
 * The static width of the dock.
 */
/**
 * plank_position_manager_get_DockWidth:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--DockWidth"><type>"DockWidth"</type></link> property.
 * 
 * The static width of the dock.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--DockWidth"><type>"DockWidth"</type></link> property
 */
/**
 * PlankPositionManager:DockBackgroundWidth:
 * 
 * The width of the dock&apos;s background image.
 */
/**
 * plank_position_manager_get_DockBackgroundWidth:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--DockBackgroundWidth"><type>"DockBackgroundWidth"</type></link> property.
 * 
 * The width of the dock&apos;s background image.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--DockBackgroundWidth"><type>"DockBackgroundWidth"</type></link> property
 */
/**
 * PlankPositionManager:MaxItemCount:
 * 
 * The maximum item count which fit the dock in its maximum size with the current theme and icon-size.
 */
/**
 * plank_position_manager_get_MaxItemCount:
 * @self: the <link linkend="PlankPositionManager"><type>PlankPositionManager</type></link> instance to query
 * 
 * Get and return the current value of the <link linkend="PlankPositionManager--MaxItemCount"><type>"MaxItemCount"</type></link> property.
 * 
 * The maximum item count which fit the dock in its maximum size with the current theme and icon-size.
 * 
 * Returns: the value of the <link linkend="PlankPositionManager--MaxItemCount"><type>"MaxItemCount"</type></link> property
 */
/**
 * PlankPositionManager:
 * 
 * Handles computing any size/position information for the dock.
 */
/**
 * PlankPositionManagerClass:
 * @parent_class: the parent class structure
 * 
 * The class structure for <link linkend="PLANK-TYPE-POSITION-MANAGER:CAPS"><literal>PLANK_TYPE_POSITION_MANAGER</literal></link>. All the fields in this structure are private and should never be accessed directly.
 */
